#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 store
version:              0.7.20
visibility:           public
id:                   store-0.7.20-JIH8V8EniVjK2eK5UZHzbi
key:                  store-0.7.20-JIH8V8EniVjK2eK5UZHzbi
license:              MIT
copyright:            2016 FP Complete
maintainer:           Michael Sloan <mgsloan@gmail.com>
homepage:             https://github.com/mgsloan/store#readme
synopsis:             Fast binary serialization
category:             Serialization, Data
abi:                  e545981f9a08cb5c12c3e4ccbd93fd26
exposed:              True
exposed-modules:
    Data.Store Data.Store.Internal Data.Store.TH Data.Store.TH.Internal
    Data.Store.TypeHash Data.Store.TypeHash.Internal Data.Store.Version
    System.IO.ByteBuffer

hidden-modules:       Data.Store.Impl
import-dirs:          /usr/lib/ghc-9.6.6/site-local/store-0.7.20
library-dirs:         /usr/lib/ghc-9.6.6/site-local/store-0.7.20
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/store-0.7.20
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-store
hs-libraries:         HSstore-0.7.20-JIH8V8EniVjK2eK5UZHzbi
depends:
    array-0.5.6.0 async-2.2.6-HlTb8qs1wHD7UNlnrqlxTX base-4.18.2.1
    base-orphans-0.9.3-JZVylsfxYah87DKDK9EEBh
    base64-bytestring-1.2.1.0-6xAAZg1ImCJ4f2ZpizqLQy
    bifunctors-5.6.3-LIHzRn6X9Du95aif640rEj bytestring-0.11.5.3
    containers-0.6.7 contravariant-1.5.6-DrebhAx4XwC59wq9S42cYg
    cryptohash-sha1-0.11.101.0-1n6qpQSH7rL4d8Ie37CZu deepseq-1.4.8.1
    directory-1.3.8.5 filepath-1.4.300.1
    free-5.2-3EKADgb5XmM9X7uhS9Tmoo ghc-prim-0.10.0
    hashable-1.4.7.0-3mscVqjFvnNHNJmw9rQ9m6
    hspec-2.11.5-IV5iN083zs8FAN90zbwfvE
    hspec-smallcheck-0.5.3-AcaHYLWGuAmI5gLyYvBbug integer-gmp-1.1
    lifted-base-0.2.3.12-Jtn29szbygG38QWn288jCx
    monad-control-1.0.3.1-3rDqCqBwApu6XpK1g6fhm1
    mono-traversable-1.0.21.0-ElljNtxPnj4DfOAFGZfMZA
    network-3.1.4.0-8vuuKMF6w9xKjPzP5P4pIh
    primitive-0.9.1.0-L0TzPG8QAUj5rYJTRwJ4yF
    resourcet-1.2.6-A7WR33a0Ijp2wXAvSf2FKK
    safe-0.3.21-2w20H2ZGSxWAicz186XsTw
    smallcheck-1.2.1.1-LIGE4TcXxo6HZ8r1WBXmt
    store-core-0.4.4.7-9wMLUq2VF9ULjNZ3kCQGVi
    syb-0.7.3-K9V4mFAbfAKIQTGSYawcKu template-haskell-2.20.0.0
    text-2.0.2 th-lift-0.8.6-259dLbfPJk9HrfYIeZHdvQ
    th-lift-instances-0.1.20-8XklgV9Q93PyAxl60BeUJ
    th-orphans-0.13.17-fFQRBBhoN7LJKhCQM8Yv6
    th-reify-many-0.1.10-2QisnA6taf4psTZd2jX03
    th-utilities-0.2.5.2-9ixLWr5CUjQ2qiZQkpHCQw time-1.12.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-CeHDQtVso2t69dwLJnxrjh
    vector-0.13.2.0-2vFNmgih5WRFjWzUm3LR1R
    void-0.7.4-Ab78HEYVlxC2PerDGXO6Wd

haddock-interfaces:   /usr/share/doc/haskell-store/html/store.haddock
haddock-html:         /usr/share/doc/haskell-store/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

